package com.glxp.mipsdl.aspect;

import cn.hutool.core.util.StrUtil;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.glxp.mipsdl.annotation.AuthRuleAnnotation;
import com.glxp.mipsdl.dao.auth.AuthLicenseDao;
import com.glxp.mipsdl.entity.auth.AuthLicense;
import com.glxp.mipsdl.enums.ResultEnum;
import com.glxp.mipsdl.exception.JsonException;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.lang.reflect.Method;
import java.util.Enumeration;

/**
 * 登录验证 AOP
 */
@Aspect
@Component
@Slf4j
public class AuthorizeAspect {

    @Resource
    private AuthLicenseDao authLicenseDao;

    @Pointcut("@annotation(com.glxp.mipsdl.annotation.AuthRuleAnnotation)")
    public void adminLoginVerify() {
    }

    /**
     * 登录验证
     *
     * @param joinPoint
     */
    @Before("adminLoginVerify()")
    public void doAdminAuthVerify(JoinPoint joinPoint) {

        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (attributes == null) {
            throw new JsonException(ResultEnum.NOT_NETWORK);
        }
        HttpServletRequest request = attributes.getRequest();
            String apiKey = request.getHeader("api_key");
            String secretKey = request.getHeader("secret_key");
            AuthLicense authLicense = authLicenseDao.keyGet(apiKey);
        if (authLicense != null && authLicense.getSecretKey().equals(secretKey)) {
        } else {
            throw new JsonException(ResultEnum.AUTH_FAILED);
        }
        // 进行权限验证
//        authRuleVerify(action.value(), adminId);
    }

    public String getAdminId(HttpServletRequest request) {
        String id = request.getHeader("ADMINID");
        if (StrUtil.isBlank(id)) {
            id = request.getHeader("ADMIN_ID");
        }
        return id;
    }

    public String getToken(HttpServletRequest request) {
        String token = request.getHeader("ADMINTOKEN");
        if (StrUtil.isBlank(token)) {
            token = request.getHeader("ADMIN_TOKEN");
        }
        return token;
    }


}
